@@ -45,11 +45,16 @@ a_xfrm_str <- function(left = 0, top = 0, width = 3, height = 3, rot = 0) {
     start_tag <- sprintf("<a:xfrm rot=\"%.0f\">", -rot * 60000)
   }
 
-  xfrm_str <- paste0(start_tag, "<a:off x=\"%.0f\" y=\"%.0f\"/><a:ext cx=\"%.0f\" cy=\"%.0f\"/></a:xfrm>")
+  xfrm_str <- paste0(
+    start_tag,
+    "<a:off x=\"%.0f\" y=\"%.0f\"/><a:ext cx=\"%.0f\" cy=\"%.0f\"/></a:xfrm>"
+  )
   sprintf(
     xfrm_str,
-    left * 914400, top * 914400,
-    width * 914400, height * 914400
+    left * 914400,
+    top * 914400,
+    width * 914400,
+    height * 914400
   )
 }
 
@@ -60,9 +65,12 @@ p_xfrm_str <- function(left = 0, top = 0, width = 3, height = 3, rot = 0) {
 
   xfrm_str <- "<p:xfrm rot=\"%.0f\"><a:off x=\"%.0f\" y=\"%.0f\"/><a:ext cx=\"%.0f\" cy=\"%.0f\"/></p:xfrm>"
   sprintf(
-    xfrm_str, -rot * 60000,
-    left * 914400, top * 914400,
-    width * 914400, height * 914400
+    xfrm_str,
+    -rot * 60000,
+    left * 914400,
+    top * 914400,
+    width * 914400,
+    height * 914400
   )
 }
 
@@ -77,7 +85,10 @@ css_color <- function(color) {
   } else {
     sprintf(
       "rgba(%.0f,%.0f,%.0f,%.2f)",
-      color[1], color[2], color[3], color[4]
+      color[1],
+      color[2],
+      color[3],
+      color[4]
     )
   }
 }
@@ -85,7 +96,9 @@ hex_color <- function(color) {
   color <- as.vector(col2rgb(color, alpha = TRUE)) / c(1, 1, 1, 255)
   sprintf(
     "%02X%02X%02X",
-    color[1], color[2], color[3]
+    color[1],
+    color[2],
+    color[3]
   )
 }
 colalpha <- function(x) {
@@ -159,7 +172,9 @@ ln_pml <- function(x) {
         tail_,
         "</a:ln>"
       ),
-      12700 * x$lwd, x$lineend, x$linecmpd
+      12700 * x$lwd,
+      x$lineend,
+      x$linecmpd
     )
   }
   ln_str
@@ -169,7 +184,13 @@ lineend_pml <- function(x, side) {
   lineend_str <- ""
   if (!is.null(x)) {
     tagname <- paste0("a:", side, "End")
-    lineend_str <- sprintf("<%s type=\"%s\" w=\"%s\" len=\"%s\"/>", tagname, x$type, x$width, x$length)
+    lineend_str <- sprintf(
+      "<%s type=\"%s\" w=\"%s\" len=\"%s\"/>",
+      tagname,
+      x$type,
+      x$width,
+      x$length
+    )
   }
   lineend_str
 }
@@ -215,11 +236,18 @@ border_pml <- function(x, side) {
   style_ <- sprintf("<a:prstDash val=\"%s\"/>", x$style)
 
   paste0(
-    "<", tagname,
-    " ", "algn=\"ctr\" cmpd=\"sng\" cap=\"flat\"",
-    " ", width_,
-    ">", color_, style_,
-    "</", tagname, ">"
+    "<",
+    tagname,
+    " ",
+    "algn=\"ctr\" cmpd=\"sng\" cap=\"flat\"",
+    " ",
+    width_,
+    ">",
+    color_,
+    style_,
+    "</",
+    tagname,
+    ">"
   )
 }
 
@@ -241,11 +269,16 @@ border_wml <- function(x, side) {
   color_ <- sprintf("w:color=\"%s\"", hex_color(x$color))
 
   paste0(
-    "<", tagname,
-    " ", style_,
-    " ", width_,
-    " ", "w:space=\"0\"",
-    " ", color_,
+    "<",
+    tagname,
+    " ",
+    style_,
+    " ",
+    width_,
+    " ",
+    "w:space=\"0\"",
+    " ",
+    color_,
     "/>"
   )
 }
@@ -261,11 +294,20 @@ border_css <- function(x, side) {
   x$style[x$style %in% "threeDEngrave"] <- "groove"
   x$style[x$style %in% "nil"] <- "none"
 
-  if (!x$style %in% c(
-    "dotted", "dashed", "solid",
-    "double", "inset", "outset",
-    "ridge", "groove", "none"
-  )) {
+  if (
+    !x$style %in%
+      c(
+        "dotted",
+        "dashed",
+        "solid",
+        "double",
+        "inset",
+        "outset",
+        "ridge",
+        "groove",
+        "none"
+      )
+  ) {
     x$style <- "solid"
   }
   paste0("border-", side, ": ", width_, " ", x$style, " ", color_, ";")
@@ -273,7 +315,6 @@ border_css <- function(x, side) {
 
 # ppr ----
 ppr_pml <- function(x) {
-
   align <- ""
   if (!is.na(x$text.align)) {
     align <- " algn=\"r\""
@@ -288,26 +329,44 @@ ppr_pml <- function(x) {
 
   leftright_padding <- ""
   if (!is.na(x$padding.left) && !is.na(x$padding.right)) {
-    leftright_padding <- sprintf(" marL=\"%.0f\" marR=\"%.0f\"", x$padding.left * 12700, x$padding.right * 12700)
+    leftright_padding <- sprintf(
+      " marL=\"%.0f\" marR=\"%.0f\"",
+      x$padding.left * 12700,
+      x$padding.right * 12700
+    )
   }
 
   top_padding <- ""
   if (!is.na(x$padding.top)) {
-    top_padding <- sprintf("<a:spcBef><a:spcPts val=\"%.0f\" /></a:spcBef>", x$padding.top * 100)
+    top_padding <- sprintf(
+      "<a:spcBef><a:spcPts val=\"%.0f\" /></a:spcBef>",
+      x$padding.top * 100
+    )
   }
   bottom_padding <- ""
   if (!is.na(x$padding.bottom)) {
-    bottom_padding <- sprintf("<a:spcAft><a:spcPts val=\"%.0f\" /></a:spcAft>", x$padding.bottom * 100)
+    bottom_padding <- sprintf(
+      "<a:spcAft><a:spcPts val=\"%.0f\" /></a:spcAft>",
+      x$padding.bottom * 100
+    )
   }
   line_spacing <- ""
   if (!is.na(x$line_spacing)) {
-    line_spacing <- sprintf("<a:lnSpc><a:spcPct val=\"%.0f\"/></a:lnSpc>", x$line_spacing * 100000)
+    line_spacing <- sprintf(
+      "<a:lnSpc><a:spcPct val=\"%.0f\"/></a:lnSpc>",
+      x$line_spacing * 100000
+    )
   }
 
   paste0(
-    "<a:pPr", align, leftright_padding, ">",
+    "<a:pPr",
+    align,
+    leftright_padding,
+    ">",
     line_spacing,
-    top_padding, bottom_padding, "<a:buNone/>",
+    top_padding,
+    bottom_padding,
+    "<a:buNone/>",
     "</a:pPr>"
   )
 }
@@ -323,15 +382,28 @@ ppr_css <- function(x) {
 
   paddings <- sprintf(
     "padding-top:%.0fpt;padding-bottom:%.0fpt;padding-left:%.0fpt;padding-right:%.0fpt;",
-    x$padding.top, x$padding.bottom, x$padding.left, x$padding.right
+    x$padding.top,
+    x$padding.bottom,
+    x$padding.left,
+    x$padding.right
+  )
+  ls <- formatC(
+    x$line_spacing,
+    format = "f",
+    digits = 2,
+    decimal.mark = ".",
+    drop0trailing = TRUE
   )
-  ls <- formatC(x$line_spacing, format = "f", digits = 2, decimal.mark = ".", drop0trailing = TRUE)
   line_spacing <- sprintf("line-height: %s;", ls)
 
   shading.color <- sprintf("background-color:%s;", css_color(x$shading.color))
 
   paste0(
-    "margin:0pt;", text.align, borders, paddings, line_spacing,
+    "margin:0pt;",
+    text.align,
+    borders,
+    paddings,
+    line_spacing,
     shading.color
   )
 }
@@ -360,16 +432,23 @@ ppr_wml <- function(x) {
   }
 
   borders_ <- ""
-  if (!is.null(x$border.top) && !isFALSE(x$border.top) &&
-      !is.null(x$border.bottom) && !isFALSE(x$border.bottom) &&
-      !is.null(x$border.left) && !isFALSE(x$border.left) &&
-      !is.null(x$border.right) && !isFALSE(x$border.right)) {
+  if (
+    !is.null(x$border.top) &&
+      !isFALSE(x$border.top) &&
+      !is.null(x$border.bottom) &&
+      !isFALSE(x$border.bottom) &&
+      !is.null(x$border.left) &&
+      !isFALSE(x$border.left) &&
+      !is.null(x$border.right) &&
+      !isFALSE(x$border.right)
+  ) {
     borders_ <- paste0(
       "<w:pBdr>",
       border_wml(x$border.bottom, "bottom"),
       border_wml(x$border.top, "top"),
       border_wml(x$border.left, "left"),
-      border_wml(x$border.right, "right"), "</w:pBdr>"
+      border_wml(x$border.right, "right"),
+      "</w:pBdr>"
     )
   }
 
@@ -377,15 +456,20 @@ ppr_wml <- function(x) {
   if (!is.na(x$padding.left) && !is.na(x$padding.right)) {
     leftright_padding <- sprintf(
       "<w:ind w:left=\"%.0f\" w:right=\"%.0f\" w:firstLine=\"0\" w:firstLineChars=\"0\"/>",
-      x$padding.left * 20, x$padding.right * 20
+      x$padding.left * 20,
+      x$padding.right * 20
     )
   }
 
   topbot_spacing <- ""
-  if (!is.na(x$padding.bottom) && !is.na(x$padding.top) && !is.na(x$line_spacing)) {
+  if (
+    !is.na(x$padding.bottom) && !is.na(x$padding.top) && !is.na(x$line_spacing)
+  ) {
     topbot_spacing <- sprintf(
       "<w:spacing w:after=\"%.0f\" w:before=\"%.0f\" w:line=\"%.0f\"/>",
-      x$padding.bottom * 20, x$padding.top * 20, x$line_spacing * 240
+      x$padding.bottom * 20,
+      x$padding.top * 20,
+      x$line_spacing * 240
     )
   }
 
@@ -484,10 +568,16 @@ rpr_pml <- function(x) {
 
   out <- paste0(
     out,
-    if (!is.na(x$font.family)) sprintf("<a:latin typeface=\"%s\"/>", x$font.family),
+    if (!is.na(x$font.family)) {
+      sprintf("<a:latin typeface=\"%s\"/>", x$font.family)
+    },
     if (!is.na(x$cs.family)) sprintf("<a:cs typeface=\"%s\"/>", x$cs.family),
-    if (!is.na(x$eastasia.family)) sprintf("<a:ea typeface=\"%s\"/>", x$eastasia.family),
-    if (!is.na(x$hansi.family)) sprintf("<a:sym typeface=\"%s\"/>", x$hansi.family)
+    if (!is.na(x$eastasia.family)) {
+      sprintf("<a:ea typeface=\"%s\"/>", x$eastasia.family)
+    },
+    if (!is.na(x$hansi.family)) {
+      sprintf("<a:sym typeface=\"%s\"/>", x$hansi.family)
+    }
   )
 
   out <- paste0(out, "</a:rPr>")
@@ -499,7 +589,9 @@ rpr_wml <- function(x) {
     "<w:rPr><w:rFonts",
     if (!is.na(x$font.family)) paste0(" w:ascii=\"", x$font.family, "\""),
     if (!is.na(x$hansi.family)) paste0(" w:hAnsi=\"", x$hansi.family, "\""),
-    if (!is.na(x$eastasia.family)) paste0(" w:eastAsia=\"", x$eastasia.family, "\""),
+    if (!is.na(x$eastasia.family)) {
+      paste0(" w:eastAsia=\"", x$eastasia.family, "\"")
+    },
     if (!is.na(x$cs.family)) paste0(" w:cs=\"", x$cs.family, "\""),
     "/>"
   )
@@ -545,7 +637,8 @@ rpr_wml <- function(x) {
       out,
       sprintf(
         "<w:sz w:val=\"%.0f\"/><w:szCs w:val=\"%.0f\"/>",
-        x$font.size * 2, x$font.size * 2
+        x$font.size * 2,
+        x$font.size * 2
       )
     )
   }
@@ -564,7 +657,10 @@ rpr_wml <- function(x) {
     if (!is_transparent(x$shading.color)) {
       out <- paste0(
         out,
-        sprintf("<w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"%s\"/>", hex_color(x$shading.color))
+        sprintf(
+          "<w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"%s\"/>",
+          hex_color(x$shading.color)
+        )
       )
     }
     if (colalpha(x$color) < 1) {
@@ -590,9 +686,15 @@ rpr_wml <- function(x) {
 rpr_css <- function(x) {
   out <- ""
 
-  if (!is.na(x$font.family)) out <- paste0(out, sprintf("font-family:'%s';", x$font.family))
-  if (!is.na(x$color)) out <- paste0(out, sprintf("color:%s;", css_color(x$color)))
-  if (!is.na(x$font.size)) out <- paste0(out, sprintf("font-size:%0.1fpt;", x$font.size))
+  if (!is.na(x$font.family)) {
+    out <- paste0(out, sprintf("font-family:'%s';", x$font.family))
+  }
+  if (!is.na(x$color)) {
+    out <- paste0(out, sprintf("color:%s;", css_color(x$color)))
+  }
+  if (!is.na(x$font.size)) {
+    out <- paste0(out, sprintf("font-size:%0.1fpt;", x$font.size))
+  }
 
   if (!is.na(x$italic)) {
     if (x$italic) {
@@ -637,7 +739,6 @@ rpr_css <- function(x) {
     out <- paste0(out, "vertical-align: sub;")
   }
 
-
   out
 }
 # tcpr ----
@@ -663,12 +764,17 @@ tcpr_pml <- function(x) {
 
   margins <- sprintf(
     " marB=\"%.0f\" marT=\"%.0f\" marR=\"%.0f\" marL=\"%.0f\"",
-    x$margin.bottom * 12700, x$margin.top * 12700,
-    x$margin.right * 12700, x$margin.left * 12700
+    x$margin.bottom * 12700,
+    x$margin.top * 12700,
+    x$margin.right * 12700,
+    x$margin.left * 12700
   )
 
   background.color <- paste0(
-    sprintf("<a:solidFill><a:srgbClr val=\"%s\">", hex_color(x$background.color)),
+    sprintf(
+      "<a:solidFill><a:srgbClr val=\"%s\">",
+      hex_color(x$background.color)
+    ),
     sprintf("<a:alpha val=\"%.0f\"/>", colalpha(x$background.color) * 100000),
     "</a:srgbClr></a:solidFill>"
   )
@@ -680,17 +786,36 @@ tcpr_pml <- function(x) {
 
   pml_attrs <- paste0(text.direction, vertical.align, margins)
   paste0(
-    "<a:tcPr", pml_attrs, ">", bl, br, bt, bb,
-    background.color, "</a:tcPr>"
+    "<a:tcPr",
+    pml_attrs,
+    ">",
+    bl,
+    br,
+    bt,
+    bb,
+    background.color,
+    "</a:tcPr>"
   )
 }
 
 tcpr_wml <- function(x) {
-  background.color <- sprintf("<w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"%s\"/>", hex_color(x$background.color))
-  vertical.align <- ifelse(x$vertical.align %in% c("center", "top"), sprintf("<w:vAlign w:val=\"%s\"/>", x$vertical.align), "<w:vAlign w:val=\"bottom\"/>")
+  background.color <- sprintf(
+    "<w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"%s\"/>",
+    hex_color(x$background.color)
+  )
+  vertical.align <- ifelse(
+    x$vertical.align %in% c("center", "top"),
+    sprintf("<w:vAlign w:val=\"%s\"/>", x$vertical.align),
+    "<w:vAlign w:val=\"bottom\"/>"
+  )
   text.direction <- ifelse(
-    x$text.direction %in% "btlr", "<w:textDirection w:val=\"btLr\"/>",
-    ifelse(x$text.direction %in% "tbrl", "<w:textDirection w:val=\"tbRl\"/>", "")
+    x$text.direction %in% "btlr",
+    "<w:textDirection w:val=\"btLr\"/>",
+    ifelse(
+      x$text.direction %in% "tbrl",
+      "<w:textDirection w:val=\"tbRl\"/>",
+      ""
+    )
   )
 
   bb <- border_wml(x$border.bottom, side = "bottom")
@@ -698,10 +823,22 @@ tcpr_wml <- function(x) {
   bl <- border_wml(x$border.left, side = "left")
   br <- border_wml(x$border.right, side = "right")
 
-  margin.bottom <- sprintf("<w:bottom w:w=\"%.0f\" w:type=\"dxa\"/>", x$margin.bottom * 20)
-  margin.top <- sprintf("<w:top w:w=\"%.0f\" w:type=\"dxa\"/>", x$margin.top * 20)
-  margin.left <- sprintf("<w:left w:w=\"%.0f\" w:type=\"dxa\"/>", x$margin.left * 20)
-  margin.right <- sprintf("<w:right w:w=\"%.0f\" w:type=\"dxa\"/>", x$margin.right * 20)
+  margin.bottom <- sprintf(
+    "<w:bottom w:w=\"%.0f\" w:type=\"dxa\"/>",
+    x$margin.bottom * 20
+  )
+  margin.top <- sprintf(
+    "<w:top w:w=\"%.0f\" w:type=\"dxa\"/>",
+    x$margin.top * 20
+  )
+  margin.left <- sprintf(
+    "<w:left w:w=\"%.0f\" w:type=\"dxa\"/>",
+    x$margin.left * 20
+  )
+  margin.right <- sprintf(
+    "<w:right w:w=\"%.0f\" w:type=\"dxa\"/>",
+    x$margin.right * 20
+  )
 
   rowspan <- ""
   if (x$rowspan > 1) {
@@ -715,31 +852,60 @@ tcpr_wml <- function(x) {
   }
 
   paste0(
-    "<w:tcPr>", rowspan, colspan,
-    "<w:tcBorders>", bb, bt, bl, br, "</w:tcBorders>",
+    "<w:tcPr>",
+    rowspan,
+    colspan,
+    "<w:tcBorders>",
+    bb,
+    bt,
+    bl,
+    br,
+    "</w:tcBorders>",
     background.color,
-    "<w:tcMar>", margin.top, margin.bottom, margin.left, margin.right, "</w:tcMar>",
-    text.direction, vertical.align, "</w:tcPr>"
+    "<w:tcMar>",
+    margin.top,
+    margin.bottom,
+    margin.left,
+    margin.right,
+    "</w:tcMar>",
+    text.direction,
+    vertical.align,
+    "</w:tcPr>"
   )
 }
 
 css_px <- function(x, format = "%.0fpx") {
-  ifelse(is.na(x), "inherit",
-    ifelse(x < 0.001, "0", sprintf(format, x))
-  )
+  ifelse(is.na(x), "inherit", ifelse(x < 0.001, "0", sprintf(format, x)))
 }
 
 tcpr_css <- function(x) {
-  background.color <- ifelse(colalpha(x$background.color) > 0,
-    sprintf("background-clip: padding-box;background-color:%s;", css_color(x$background.color)),
+  background.color <- ifelse(
+    colalpha(x$background.color) > 0,
+    sprintf(
+      "background-clip: padding-box;background-color:%s;",
+      css_color(x$background.color)
+    ),
     "background-color:transparent;"
   )
 
-  width <- ifelse(is.null(x$width) || is.na(x$width), "", sprintf("width:%s;", css_px(x$width * 72)))
-  height <- ifelse(is.null(x$height) || is.na(x$height), "", sprintf("height:%s;", css_px(x$height * 72)))
+  width <- ifelse(
+    is.null(x$width) || is.na(x$width),
+    "",
+    sprintf("width:%s;", css_px(x$width * 72))
+  )
+  height <- ifelse(
+    is.null(x$height) || is.na(x$height),
+    "",
+    sprintf("height:%s;", css_px(x$height * 72))
+  )
   vertical.align <- ifelse(
-    x$vertical.align %in% "center", "vertical-align:middle;",
-    ifelse(x$vertical.align %in% "top", "vertical-align:top;", "vertical-align:bottom;")
+    x$vertical.align %in% "center",
+    "vertical-align:middle;",
+    ifelse(
+      x$vertical.align %in% "top",
+      "vertical-align:top;",
+      "vertical-align:bottom;"
+    )
   )
 
   bb <- border_css(x$border.bottom, side = "bottom")
@@ -747,13 +913,26 @@ tcpr_css <- function(x) {
   bl <- border_css(x$border.left, side = "left")
   br <- border_css(x$border.right, side = "right")
 
-  margin.bottom <- sprintf("margin-bottom:%s;", sprintf("%.0fpt", x$margin.bottom))
+  margin.bottom <- sprintf(
+    "margin-bottom:%s;",
+    sprintf("%.0fpt", x$margin.bottom)
+  )
   margin.top <- sprintf("margin-top:%s;", sprintf("%.0fpt", x$margin.top))
   margin.left <- sprintf("margin-left:%s;", sprintf("%.0fpt", x$margin.left))
   margin.right <- sprintf("margin-right:%s;", sprintf("%.0fpt", x$margin.right))
 
   paste0(
-    width, height, background.color, vertical.align, bb, bt, bl, br,
-    margin.bottom, margin.top, margin.left, margin.right
+    width,
+    height,
+    background.color,
+    vertical.align,
+    bb,
+    bt,
+    bl,
+    br,
+    margin.bottom,
+    margin.top,
+    margin.left,
+    margin.right
   )
 }
