@@ -1,8 +1,7 @@
 #' @title shortcuts for formatting properties
 #'
 #' @description
-#' Shortcuts for \code{fp_text}, \code{fp_par},
-#' \code{fp_cell} and \code{fp_border}.
+#' Shortcuts for [fp_text()], [fp_par()], [fp_cell()] and [fp_border()].
 #' @name shortcuts
 #' @examples
 #' shortcuts$fp_bold()
@@ -16,9 +15,13 @@ NULL
 #' @keywords NULL
 #' @export
 shortcuts <- list(
-  fp_bold = function(...) {fp_text( bold = TRUE, ... )},
-  fp_italic = function( ... ) {fp_text( italic = TRUE, ... )},
-  b_null = function( ... )  {fp_border( width = 0, ... )}
+  fp_bold = function(...) {
+    fp_text(bold = TRUE, ...)
+  },
+  fp_italic = function(...) {
+    fp_text(italic = TRUE, ...)
+  },
+  b_null = function(...) {
+    fp_border(width = 0, ...)
+  }
 )
-
-
